<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 * @return array An array of default values
 */

function next_travel_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$next_travel_pro_default_options = array(
		'search_icon_in_primary_menu_enable' => true,
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#F38625',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		'social_menu_enable'			=>true,
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'next-travel-pro' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,about,gallery_slider,popular_destination,counter,featured_posts,recommended_destination,subscription,testimonial,blog,service,team,latest_products,popular_products,collection,recent_products,featured_products,trending_product,recent_news',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'next-travel-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'blog_page_button' 				=> esc_html__( 'READ MORE', 'next-travel-pro' ),
		'blog_column'					=> 'col-1',

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Slider
		'slider_section_enable'			=> true,
		'slider_autoplay'				=> false,
		'slider_btn_label' 				=> esc_html__( 'Learn More', 'next-travel-pro' ),
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_excerpt_length'			=> 25,
		'slider_search_enable'			=> true,

		// about
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'TRAVEL & TOUR', 'next-travel-pro' ),
		'about_sub_title'				=> esc_html__( 'About', 'next-travel-pro' ),
		'about_description'				=> esc_html__( 'Lots of people are traveling the entire world. They have got their own purposes. You can also travel the world. We will tell you how to travel the river, sea, hilly areas, mountain & so on...', 'next-travel-pro' ),
		'about_btn_title'				=> esc_html__( 'LEARN ABOUT US', 'next-travel-pro' ),
		'about_excerpt_length'			=> 25,

		// Gallery Slider
		'gallery_slider_section_enable'			=> true,
		'gallery_slider_autoplay'				=> false,
		'gallery_slider_btn_title'				=> esc_html__( 'Explore More', 'next-travel-pro' ),
		'gallery_slider_content_type'			=> 'category',
		'gallery_slider_count'					=> 5,

		// popular destination
		'popular_destination_section_enable'	=> true,
		'popular_destination_content_type'		=> 'category',
		'popular_destination_description'		=> esc_html__( 'Bacon ipsum dolor amet kevin picanha sausage corned beef chuck shankle kielbasa chicken meatloaf t-bone buffalo. Pork chop pork belly shank sirloin tri-tip ham alcatra turkey bacon buffalo kielbasa pancetta....', 'next-travel-pro' ),
		'popular_destination_title'				=> esc_html__('DESTINATION','next-travel-pro'),
		'popular_destination_sub_title'			=> esc_html__('Top Travel','next-travel-pro'),
		'popular_destination_post_btn_label'	=> esc_html__( 'Read More', 'next-travel-pro' ),
		'popular_destination_btn_label'			=> esc_html__( 'DISCOVER MORE', 'next-travel-pro' ),

		// counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',
		'counter_sub_title'				=> esc_html__( 'Our Experience', 'next-travel-pro' ),
		'counter_title'					=> esc_html__( 'ADVENTURE STARTS HERE', 'next-travel-pro' ),

		// recommended destination
		'recommended_destination_section_enable'	=> true,
		'recommended_destination_content_type'		=> 'category',
		'recommended_destination_description'		=> esc_html__( 'Lots of people are traveling the entire world. They have got their own purposes. You can also travel the world. We will tell you how to travel the river, sea, hilly areas, mountain & so on...', 'next-travel-pro' ),
		'recommended_destination_title'				=> esc_html__('HOTELS & LODGES','next-travel-pro'),
		'recommended_destination_sub_title'			=> esc_html__('Recommended','next-travel-pro'),
		'recommended_destination_post_btn_label'	=> esc_html__( 'Read More', 'next-travel-pro' ),
		'recommended_destination_btn_label'			=> esc_html__( 'VIEW ALL HOTELS', 'next-travel-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_sub_title'				=> esc_html__('Featured', 'next-travel-pro'),
		'blog_title'					=> esc_html__( 'NEWS & ARTICLES', 'next-travel-pro' ),
		'blog_content_type'				=> 'recent',
		'blog_excerpt_length'			=> 30,

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_excerpt_length'		=> 25,
		'service_sub_title'				=> esc_html('Service', 'next-travel-pro'),
		'service_title'					=> esc_html('WHAT WE DO', 'next-travel-pro'),
		
		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_auto_play'			=> false,
		'testimonial_title'				=> esc_html__( 'WHAT PEOPLE SAYS', 'next-travel-pro' ),
		'testimonial_sub_title'			=> esc_html__( 'Testimonials', 'next-travel-pro' ),
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 3,
		'testimonial_excerpt_length'	=> 30,

		// team
		'team_section_enable'		=> true,
		'team_content_type'			=> 'category',
		'team_count'				=> 3,
		'team_excerpt_length'		=> 20,
		'team_sub_title'			=> esc_html('MEET OUR STAFFS', 'next-travel-pro'),
		'team_title'				=> esc_html('Team', 'next-travel-pro'),

		// recent_news
		'recent_news_section_enable'	=> true,
		'recent_news_title'				=> esc_html__( 'OUR LATEST NEWS', 'next-travel-pro' ),
		'recent_news_sub_title'			=> esc_html__( 'Articles', 'next-travel-pro' ),
		'recent_news_button'			=> esc_html__( 'Learn More', 'next-travel-pro' ),
		'recent_news_content_type'		=> 'category',
		'recent_news_count'				=> 3,
		'recent_news_excerpt_length'	=> 30,

		// featured_posts
		'featured_posts_section_enable'	=> true,
		'featured_posts_content_type'		=> 'category',
		'featured_posts_count'				=> 3,

		// latest products
		'latest_products_section_enable'	=> false,
		'latest_products_count'				=> 2,
		'latest_products_content_type'		=> 'product-category',

		//popular products
		'popular_products_section_enable'		=> false,
		'popular_products_content_type'			=> 'product-category',
		'popular_products_count'				=> 4,
		'popular_products_title'				=> esc_html__( 'Shopping Every Day', 'next-travel-pro' ),
		'popular_products_sub_title'			=> esc_html__( 'PRODUCTS', 'next-travel-pro' ),

		//popular collection
		'collection_section_enable'		=> false,
		'collection_title'				=> esc_html__( 'PRODUCTS COLLECTION', 'next-travel-pro' ),
		'collection_subtitle'			=> esc_html__( 'Shop', 'next-travel-pro' ),

		//recent products
		'recent_products_section_enable'	=> false,
		'recent_products_content_type'		=> 'product-category',
		'recent_products_count'				=> 4,
		'recent_products_title'				=> esc_html__( 'RECENT PRODUCTS', 'next-travel-pro' ),
		'recent_products_sub_title'			=> esc_html__( 'Trending', 'next-travel-pro' ),

		//featured section
		'featured_products_section_enable'		=> false,

		//trending_product 
		'trending_product_section_enable'				=> false,
		'trending_product_count'						=> 3,

		// subscription
		'subscription_section_enable'	=> true,
		'subscription_sub_title'		=> esc_html__( 'Subscribe', 'next-travel-pro' ),
		'subscription_title'			=> esc_html__( 'TRAVEL WITH US', 'next-travel-pro' ),
		'subscription_description'		=> esc_html__( 'We recommend you to subscribe to our newpaper, enter your email address below to get daily update about travel & tourism.', 'next-travel-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'next-travel-pro' ),

	);

	$output = apply_filters( 'next_travel_pro_default_theme_options', $next_travel_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}