<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'next_travel_pro_counter_section', array(
	'title'             => esc_html__( 'Counters','next-travel-pro' ),
	'description'       => esc_html__( 'Counters Section options.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_counter_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[counter_section_enable]', array(
		'selector'            => '#counter-section .tooltiptext',
		'settings'            => 'next_travel_pro_theme_options[counter_section_enable]',
    ) );
}

if( in_array( $options['home_layout'], array( 'default-design-all', 'default-design', 'fourth-design', 'sixth-design' ) ) ):

// Counter sub title control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[counter_sub_title]', array(
    'default'           => $options['counter_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[counter_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_counter_section',
	'active_callback' 	=> 'next_travel_pro_is_counter_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[counter_sub_title]', array(
		'selector'            => '#counter-section h3.section-subtitle',
		'settings'            => 'next_travel_pro_theme_options[counter_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_counter_sub_title_partial',
    ) );
}

// Counter sub title control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[counter_title]', array(
    'default'           => $options['counter_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[counter_title]', array(
	'label'           	=> esc_html__( 'Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_counter_section',
	'active_callback' 	=> 'next_travel_pro_is_counter_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[counter_title]', array(
		'selector'            => '#counter-section h2.section-title',
		'settings'            => 'next_travel_pro_theme_options[counter_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_counter_title_partial',
    ) );
}

endif;

// counter content type control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[counter_column]', array(
	'default'          	=> $options['counter_column'],
	'sanitize_callback' => 'next_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[counter_column]', array(
	'label'             => esc_html__( 'Column Layout', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_counter_section',
	'type'				=> 'select',
	'active_callback' 	=> 'next_travel_pro_is_counter_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'next-travel-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'next-travel-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'next-travel-pro' ),
	),
) );

$wp_customize->add_setting( 'next_travel_pro_theme_options[counter_image]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'next_travel_pro_theme_options[counter_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'next-travel-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'next-travel-pro' ), 1350, 385 ),
		'section'     		=> 'next_travel_pro_counter_section',
		'active_callback'	=> 'next_travel_pro_is_counter_section_enable',
) ) );

// counter number control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'next_travel_pro_sanitize_number_range',
	'validate_callback' => 'next_travel_pro_validate_counter_count',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counters', 'next-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_counter_section',
	'active_callback'   => 'next_travel_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	// counter title setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'next_travel_pro_theme_options[counter_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'next-travel-pro' ), $i ),
		'section'        	=> 'next_travel_pro_counter_section',
		'active_callback' 	=> 'next_travel_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter title setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'next_travel_pro_theme_options[counter_number_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'next-travel-pro' ), $i ),
		'section'        	=> 'next_travel_pro_counter_section',
		'active_callback' 	=> 'next_travel_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'next_travel_pro_counter_section',
			'active_callback' => 'next_travel_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// counter hr setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[counter_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[counter_hr]',
	array(
		'section'         => 'next_travel_pro_counter_section',
		'active_callback' => 'next_travel_pro_is_counter_section_enable',
		'type'			  => 'hr'
		) ) );

require get_template_directory() . '/inc/customizer/sections/color/counter.php';


