<?php
/**
 * Gallery Slider Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

// Add Gallery Slider section
$wp_customize->add_section( 'next_travel_pro_gallery_slider_section', array(
	'title'             => esc_html__( 'Gallery Slider','next-travel-pro' ),
	'description'       => esc_html__( 'Gallery Slider Section options.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// Gallery Slider section enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[gallery_slider_section_enable]', array(
	'default'			=> 	$options['gallery_slider_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[gallery_slider_section_enable]', array(
	'label'             => esc_html__( 'Gallery Slider Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_gallery_slider_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[gallery_slider_section_enable]', array(
		'selector'            => '#gallery-slider-section .tooltiptext',
		'settings'            => 'next_travel_pro_theme_options[gallery_slider_section_enable]',
    ) );
}

// Gallery Slider autoplay enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[gallery_slider_autoplay]', array(
	'default'			=> 	$options['gallery_slider_autoplay'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[gallery_slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_gallery_slider_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
	'active_callback' 	=> 'next_travel_pro_is_gallery_slider_section_enable',
) ) );

// Gallery Slider post count number control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[gallery_slider_count]', array(
	'default'          	=> $options['gallery_slider_count'],
	'sanitize_callback' => 'next_travel_pro_sanitize_number_range',
	'validate_callback' => 'next_travel_pro_validate_gallery_slider_count',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[gallery_slider_count]', array(
	'label'             => esc_html__( 'Number of Gallery Slides', 'next-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_gallery_slider_section',
	'active_callback'   => 'next_travel_pro_is_gallery_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Gallery Slider content type control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[gallery_slider_content_type]', array(
	'default'          	=> $options['gallery_slider_content_type'],
	'sanitize_callback' => 'next_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[gallery_slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_gallery_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'next_travel_pro_is_gallery_slider_section_enable',
	'choices'			=> next_travel_pro_gallery_slider_content_type(),
) );

for ( $i = 1; $i <= $options['gallery_slider_count']; $i++ ) :

	// testimonial position setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[gallery_slider_subtitle_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'next_travel_pro_theme_options[gallery_slider_subtitle_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Sub Title %d', 'next-travel-pro' ), $i ),
		'section'        	=> 'next_travel_pro_gallery_slider_section',
		'active_callback' 	=> 'next_travel_pro_is_gallery_slider_section_enable',
		'type'				=> 'text',
	) );

	// gallery_slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[gallery_slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[gallery_slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_gallery_slider_section',
		'choices'			=> next_travel_pro_page_choices(),
		'active_callback'	=> 'next_travel_pro_is_gallery_slider_section_content_page_enable',
	) ) );

	// gallery_slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[gallery_slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[gallery_slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_gallery_slider_section',
		'choices'			=> next_travel_pro_post_choices(),
		'active_callback'	=> 'next_travel_pro_is_gallery_slider_section_content_post_enable',
	) ) );

	// Gallery Slider trips drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[gallery_slider_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[gallery_slider_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_gallery_slider_section',
		'choices'			=> next_travel_pro_trip_choices(),
		'active_callback'	=> 'next_travel_pro_is_gallery_slider_section_content_trip_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[gallery_slider_content_category]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[gallery_slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'next-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_gallery_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_gallery_slider_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[gallery_slider_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[gallery_slider_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_gallery_slider_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_gallery_slider_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[gallery_slider_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[gallery_slider_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_gallery_slider_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_gallery_slider_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[gallery_slider_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[gallery_slider_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_gallery_slider_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_gallery_slider_section_content_destination_enable'
) ) );

// gallery_slider btn title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[gallery_slider_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_slider_btn_title'],
	'transport'			=> 'postMessage',
	) );
	
	$wp_customize->add_control( 'next_travel_pro_theme_options[gallery_slider_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_gallery_slider_section',
	'active_callback' 	=> 'next_travel_pro_is_gallery_slider_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[gallery_slider_btn_title]', array(
		'selector'            => '#gallery-slider-section div.read-more a',
		'settings'            => 'next_travel_pro_theme_options[gallery_slider_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_gallery_slider_btn_title_partial',
		) );
	}

// gallery_slider hr setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[gallery_slider_hr]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[gallery_slider_hr]',
		array(
			'section'         => 'next_travel_pro_gallery_slider_section',
			'active_callback' => 'next_travel_pro_is_gallery_slider_section_enable',
			'type'			  => 'hr'
	) ) );

require get_template_directory() . '/inc/customizer/sections/color/gallery-slider.php';