<?php
/**
 * Popular Products Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add popular_products section
$wp_customize->add_section( 'next_travel_pro_popular_products_section', array(
    'title'             => esc_html__( 'Popular Product','next-travel-pro' ),
    'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'next-travel-pro' ),
    'panel'             => 'next_travel_pro_front_page_panel',
) );

// popular_products content enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[popular_products_section_enable]', array(
    'default'           =>  $options['popular_products_section_enable'],
    'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[popular_products_section_enable]', array(
    'label'             => esc_html__( 'Popular product Section Enable', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_popular_products_section',
    'on_off_label'      => next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[popular_products_section_enable]', array(
        'selector'            => '#popular-products .tooltiptext',
        'settings'            => 'next_travel_pro_theme_options[popular_products_section_enable]',
    ) );
}

// popular_products title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[popular_products_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['popular_products_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[popular_products_title]', array(
    'label'             => esc_html__( 'Title', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_popular_products_section',
    'active_callback'   => 'next_travel_pro_is_popular_products_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[popular_products_title]', array(
        'selector'            => '#popular-products h2.section-title',
        'settings'            => 'next_travel_pro_theme_options[popular_products_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'next_travel_pro_popular_products_title_partial',
    ) );
}

// popular_products title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[popular_products_sub_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['popular_products_sub_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[popular_products_sub_title]', array(
    'label'             => esc_html__( 'Sub Title', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_popular_products_section',
    'active_callback'   => 'next_travel_pro_is_popular_products_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[popular_products_sub_title]', array(
        'selector'            => '#popular-products h3.section-subtitle',
        'settings'            => 'next_travel_pro_theme_options[popular_products_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'next_travel_pro_popular_products_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'next_travel_pro_theme_options[popular_products_count]', array(
    'default'           => $options['popular_products_count'],
    'sanitize_callback' => 'next_travel_pro_sanitize_number_range',
    'validate_callback' => 'next_travel_pro_validate_popular_products_count',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[popular_products_count]', array(
    'label'             => esc_html__( 'Number of Product', 'next-travel-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_popular_products_section',
    'active_callback'   => 'next_travel_pro_is_popular_products_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'next_travel_pro_theme_options[popular_products_content_type]', array(
    'default'           => $options['popular_products_content_type'],
    'sanitize_callback' => 'next_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[popular_products_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_popular_products_section',
    'type'              => 'select',
    'active_callback'   => 'next_travel_pro_is_popular_products_section_enable',
    'choices'           => array(
        'product'           => esc_html__( 'Product', 'next-travel-pro' ),
        'product-category'  => esc_html__( 'Product Category', 'next-travel-pro' ),
        ),
) );

for( $i = 1 ; $i <= $options['popular_products_count'] ; $i++ ){

    $wp_customize->add_setting( 'next_travel_pro_theme_options[popular_products_content_page_' . $i . ']', array(
        'sanitize_callback' => 'next_travel_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[popular_products_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'next-travel-pro' ), $i ),
        'section'           => 'next_travel_pro_popular_products_section',
        'choices'           => next_travel_pro_product_choices(),
        'active_callback'   => 'next_travel_pro_is_popular_products_section_content_product_enable',
    ) ) );
}

$wp_customize->add_setting(  'next_travel_pro_theme_options[popular_products_category]', array(
        'sanitize_callback' => 'absint',
    ) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[popular_products_category]', array(
    'label'             => esc_html__( 'Select Product Categories', 'next-travel-pro' ),
    'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_popular_products_section',
    'taxonomy'          => 'product_cat',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'next_travel_pro_is_popular_products_section_content_product_category_enable',
) ) );

// popular_products hr setting and control
    $wp_customize->add_setting( 'next_travel_pro_theme_options[popular_products_hr]', array(
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[popular_products_hr]',
        array(
            'section'         => 'next_travel_pro_popular_products_section',
            'active_callback' => 'next_travel_pro_is_popular_products_section_enable',
            'type'            => 'hr'
    ) ) );
    
//color options

// Section background color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[popular_products_bg_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[popular_products_bg_color]', array(
    'label'             => esc_html__( 'Background Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_popular_products_section',
    'active_callback'   => 'next_travel_pro_is_popular_products_section_enable',
    ) ) );

// Section sub title color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[popular_products_sub_title_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[popular_products_sub_title_color]', array(
    'label'             => esc_html__( 'Section Sub Title Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_popular_products_section',
    'active_callback'   => 'next_travel_pro_is_popular_products_section_enable',
    ) ) );

// Section sub title color setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[popular_products_title_color]', array(
    'sanitize_callback' => 'sanitize_hex_color',
    'transport'         => 'refresh'
    ) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'next_travel_pro_theme_options[popular_products_title_color]', array(
    'label'             => esc_html__( 'Section Title Color', 'next-travel-pro' ),
    'section'           => 'next_travel_pro_popular_products_section',
    'active_callback'   => 'next_travel_pro_is_popular_products_section_enable',
    ) ) );