<?php
/**
 * Recent News Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

// Add Recent News section
$wp_customize->add_section( 'next_travel_pro_recent_news_section', array(
	'title'             => esc_html__( 'Recent News','next-travel-pro' ),
	'description'       => esc_html__( 'Recent News Section options.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// Recent News content enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[recent_news_section_enable]', array(
	'default'			=> 	$options['recent_news_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[recent_news_section_enable]', array(
	'label'             => esc_html__( 'Recent News Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_recent_news_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[recent_news_section_enable]', array(
		'selector'            => '#recent-news .tooltiptext',
		'settings'            => 'next_travel_pro_theme_options[recent_news_section_enable]',
    ) );
}

$wp_customize->add_setting( 'next_travel_pro_theme_options[recent_news_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_news_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recent_news_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_recent_news_section',
	'active_callback' 	=> 'next_travel_pro_is_recent_news_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[recent_news_sub_title]', array(
		'selector'            => '#recent-news h3.section-subtitle',
		'settings'            => 'next_travel_pro_theme_options[recent_news_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_recent_news_sub_title_partial',
    ) );
}

// recent_news title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[recent_news_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_news_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recent_news_title]', array(
	'label'           	=> esc_html__( 'Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_recent_news_section',
	'active_callback' 	=> 'next_travel_pro_is_recent_news_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[recent_news_title]', array(
		'selector'            => '#recent-news h2.section-title',
		'settings'            => 'next_travel_pro_theme_options[recent_news_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_recent_news_title_partial',
    ) );
}

// Recent News post  number control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[recent_news_count]', array(
	'default'          	=> $options['recent_news_count'],
	'sanitize_callback' => 'next_travel_pro_sanitize_number_range',
	'validate_callback' => 'next_travel_pro_validate_recent_news_count',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recent_news_count]', array(
	'label'             => esc_html__( 'Number of Recent Newss', 'next-travel-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_recent_news_section',
	'active_callback'   => 'next_travel_pro_is_recent_news_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[recent_news_excerpt_length]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_number_range',
	'validate_callback' => 'next_travel_pro_validate_long_excerpt',
	'default'			=> $options['recent_news_excerpt_length'],
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recent_news_excerpt_length]', array(
	'label'       		=> esc_html__( 'Slider Excerpt Length', 'next-travel-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in recent_news posts.', 'next-travel-pro' ),
	'section'     		=> 'next_travel_pro_recent_news_section',	
	'active_callback' 	=> 'next_travel_pro_is_recent_news_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// recent_news title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[recent_news_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_news_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recent_news_button]', array(
	'label'           	=> esc_html__( 'Button Label', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_recent_news_section',
	'active_callback' 	=> 'next_travel_pro_is_recent_news_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[recent_news_button]', array(
		'selector'            => '#recent-news div.read-more a.btn',
		'settings'            => 'next_travel_pro_theme_options[recent_news_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_recent_news_button_partial',
    ) );
}

// Recent News content type control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[recent_news_content_type]', array(
	'default'          	=> $options['recent_news_content_type'],
	'sanitize_callback' => 'next_travel_pro_sanitize_select',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[recent_news_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_recent_news_section',
	'type'				=> 'select',
	'active_callback' 	=> 'next_travel_pro_is_recent_news_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'next-travel-pro' ),
		'post' 		=> esc_html__( 'Post', 'next-travel-pro' ),
		'category' 	=> esc_html__( 'Category', 'next-travel-pro' ),
	),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'next_travel_pro_theme_options[recent_news_content_category]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Taxonomies_Control( $wp_customize,'next_travel_pro_theme_options[recent_news_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'next-travel-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_recent_news_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'next_travel_pro_is_recent_news_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['recent_news_count']; $i++ ) :
	// recent_news pages drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[recent_news_content_page_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[recent_news_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_recent_news_section',
		'choices'			=> next_travel_pro_page_choices(),
		'active_callback'	=> 'next_travel_pro_is_recent_news_section_content_page_enable',
	) ) );

	// recent_news posts drop down chooser control and setting
	$wp_customize->add_setting( 'next_travel_pro_theme_options[recent_news_content_post_' . $i . ']', array(
		'sanitize_callback' => 'next_travel_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Dropdown_Chooser( $wp_customize, 'next_travel_pro_theme_options[recent_news_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'next-travel-pro' ), $i ),
		'section'           => 'next_travel_pro_recent_news_section',
		'choices'			=> next_travel_pro_post_choices(),
		'active_callback'	=> 'next_travel_pro_is_recent_news_section_content_post_enable',
	) ) );

endfor;

// recent_news hr setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[recent_news_hr]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[recent_news_hr]',
		array(
			'section'         => 'next_travel_pro_recent_news_section',
			'active_callback' => 'next_travel_pro_is_recent_news_section_enable',
			'type'			  => 'hr'
	) ) );

	require get_template_directory() . '/inc/customizer/sections/color/recent-news.php';

