<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

// Add Subscription section
$wp_customize->add_section( 'next_travel_pro_subscription_section', array(
	'title'             => esc_html__( 'Subscription','next-travel-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'next-travel-pro' ),
	'panel'             => 'next_travel_pro_front_page_panel',
) );

// Subscription content enable control and setting
$wp_customize->add_setting( 'next_travel_pro_theme_options[subscription_section_enable]', array(
	'default'			=> 	$options['subscription_section_enable'],
	'sanitize_callback' => 'next_travel_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Next_Travel_Pro_Switch_Control( $wp_customize, 'next_travel_pro_theme_options[subscription_section_enable]', array(
	'label'             => esc_html__( 'Subscription Section Enable', 'next-travel-pro' ),
	'section'           => 'next_travel_pro_subscription_section',
	'on_off_label' 		=> next_travel_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[subscription_section_enable]', array(
		'selector'            => '#subscribe-now .tooltiptext',
		'settings'            => 'next_travel_pro_theme_options[subscription_section_enable]',
    ) );
}

// subscription  background image setting and control.
$wp_customize->add_setting( 'next_travel_pro_theme_options[subscription_bg_image]', array(
	'sanitize_callback' => 'next_travel_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'next_travel_pro_theme_options[subscription_bg_image]',
		array(
		'label'       		=> esc_html__( 'subscription Background Image', 'next-travel-pro'),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'next-travel-pro' ), 1920, 600 ),
		'section'     		=> 'next_travel_pro_subscription_section',
		'active_callback'	=> 'next_travel_pro_is_subscription_section_enable',
) ) );

// subscription sub title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[subscription_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[subscription_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_subscription_section',
	'active_callback' 	=> 'next_travel_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[subscription_sub_title]', array(
		'selector'            => '#subscribe-now div.section-header',
		'settings'            => 'next_travel_pro_theme_options[subscription_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_subscription_sub_title_partial',
    ) );
}

// subscription title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[subscription_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[subscription_title]', array(
	'label'           	=> esc_html__( 'Title', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_subscription_section',
	'active_callback' 	=> 'next_travel_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[subscription_title]', array(
		'selector'            => '#subscribe-now h2.section-title',
		'settings'            => 'next_travel_pro_theme_options[subscription_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_subscription_title_partial',
    ) );
}

// subscription description setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[subscription_description]', array(
	'sanitize_callback' => 'wp_kses_post',	
	'default'			=> $options['subscription_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[subscription_description]', array(
	'label'           	=> esc_html__( 'Description', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_subscription_section',
	'active_callback' 	=> 'next_travel_pro_is_subscription_section_enable',
	'type'				=> 'textarea',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'next_travel_pro_theme_options[subscription_description]', array(
		'selector'            => '#subscribe-now div.entry-content',
		'settings'            => 'next_travel_pro_theme_options[subscription_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'next_travel_pro_subscription_description_partial',
    ) );
}

// subscription btn title setting and control
$wp_customize->add_setting( 'next_travel_pro_theme_options[subscription_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscription_btn_title'],
) );

$wp_customize->add_control( 'next_travel_pro_theme_options[subscription_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'next-travel-pro' ),
	'section'        	=> 'next_travel_pro_subscription_section',
	'active_callback' 	=> 'next_travel_pro_is_subscription_section_enable',
	'type'				=> 'text',
) );

// subscription hr setting and control
	$wp_customize->add_setting( 'next_travel_pro_theme_options[subscription_hr]', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Next_Travel_Pro_Customize_Horizontal_Line( $wp_customize, 'next_travel_pro_theme_options[subscription_hr]',
		array(
			'section'         => 'next_travel_pro_subscription_section',
			'active_callback' => 'next_travel_pro_is_subscription_section_enable',
			'type'			  => 'hr'
	) ) );

	require get_template_directory() . '/inc/customizer/sections/color/subscription.php';

