<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function next_travel_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'next-travel-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function next_travel_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'next-travel-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function next_travel_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'next-travel-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

function next_travel_pro_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'next-travel-pro' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}

if ( ! function_exists( 'next_travel_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function next_travel_pro_typography_options(){
        $font_family_arr = array();
        $font_family_arr[''] = esc_html__( '--Default--', 'next-travel-pro' );

        // Make the request
        $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

        if( is_wp_error( $request ) ) {
            return false; // Bail early
        }
        // Retrieve the data
        $body = wp_remote_retrieve_body( $request );
        $data = json_decode( $body );
        if ( ! empty( $data ) ) {
            foreach ( $data->items as $items => $fonts ) {
                $family_str_arr = explode( ' ', $fonts->family );
                $family_value = implode( '+', $family_str_arr );
                $font_family_arr[ $family_value ] = $fonts->family;
            }
        }

        return $font_family_arr;
    }
endif;


if ( ! function_exists( 'next_travel_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function next_travel_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'next-travel-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'next-travel-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'next-travel-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'next-travel-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'next-travel-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'next-travel-pro' ),
        );

        $output = apply_filters( 'next_travel_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'next_travel_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function next_travel_pro_selected_sidebar() {
        $next_travel_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'next-travel-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'next-travel-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'next-travel-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'next-travel-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'next-travel-pro' ),
        );

        $output = apply_filters( 'next_travel_pro_selected_sidebar', $next_travel_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'next_travel_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function next_travel_pro_site_layout() {
        $next_travel_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'next_travel_pro_site_layout', $next_travel_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'next_travel_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function next_travel_pro_global_sidebar_position() {
        $next_travel_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'next_travel_pro_global_sidebar_position', $next_travel_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'next_travel_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function next_travel_pro_sidebar_position() {
        $next_travel_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'next_travel_pro_sidebar_position', $next_travel_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'next_travel_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function next_travel_pro_pagination_options() {
        $next_travel_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'next-travel-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'next-travel-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'next-travel-pro' ),
        );

        $output = apply_filters( 'next_travel_pro_pagination_options', $next_travel_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'next_travel_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function next_travel_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'next-travel-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'next-travel-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'next-travel-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'next-travel-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'next-travel-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'next-travel-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'next-travel-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'next-travel-pro' ),
        );
        return apply_filters( 'next_travel_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'next_travel_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function next_travel_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'next-travel-pro' ),
            'off'       => esc_html__( 'Disable', 'next-travel-pro' )
        );
        return apply_filters( 'next_travel_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'next_travel_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function next_travel_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'next-travel-pro' ),
            'off'       => esc_html__( 'No', 'next-travel-pro' )
        );
        return apply_filters( 'next_travel_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'next_travel_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function next_travel_pro_sortable_sections() {
        $sections = array(
        'slider'                    => esc_html__( 'Slider', 'next-travel-pro' ),
        'about'                     => esc_html__( 'About Us', 'next-travel-pro' ),
        'gallery_slider'            => esc_html__( 'Gallery Slider', 'next-travel-pro' ),
        'popular_destination'       => esc_html__( 'Popular Destination', 'next-travel-pro' ),
        'counter'                   => esc_html__( 'Counter', 'next-travel-pro' ),
        'featured_posts'            => esc_html__( 'Featured Posts', 'next-travel-pro' ),
        'recommended_destination'   => esc_html__( 'Recommended Destination', 'next-travel-pro' ),
        'subscription'              => esc_html__( 'Subscription', 'next-travel-pro' ),
        'testimonial'               => esc_html__( 'Testimonial', 'next-travel-pro' ),
        'blog'                      => esc_html__( 'Blog', 'next-travel-pro' ),
        'service'                   => esc_html__( 'Service', 'next-travel-pro' ),
        'team'                      => esc_html__( 'Team', 'next-travel-pro' ),
        'latest_products'           => esc_html__( 'Latest Products', 'next-travel-pro' ),
        'popular_products'          => esc_html__( 'Popular Products', 'next-travel-pro' ),
        'collection'                => esc_html__( 'Products Collection', 'next-travel-pro' ),
        'recent_products'           => esc_html__( 'Recent Products', 'next-travel-pro' ),
        'featured_products'         => esc_html__( 'Featured Products', 'next-travel-pro' ),
        'trending_product'          => esc_html__( 'Trending Products', 'next-travel-pro' ),
        'recent_news'               => esc_html__( 'Recent News', 'next-travel-pro' ),
        );
        
        return apply_filters( 'next_travel_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'next_travel_pro_slider_content_type' ) ) :
    /**
     * slider Options
     * @return array site slider options
     */
    function next_travel_pro_slider_content_type() {
      
        $next_travel_pro_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'next-travel-pro' ),
            'post'      => esc_html__( 'Post', 'next-travel-pro' ),
            'category'  => esc_html__( 'Category', 'next-travel-pro' ),
        );

        if ( class_exists( 'WP_Travel' )) {
            $next_travel_pro_slider_content_type = array_merge( $next_travel_pro_slider_content_type, array(
                'trip'          => esc_html__( 'Trip', 'next-travel-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'next-travel-pro' ),
                'destination'   => esc_html__( 'Destination', 'next-travel-pro' ),
                'activity'      => esc_html__( 'Activity', 'next-travel-pro' ),
                ) );
        }

        $output = apply_filters( 'next_travel_pro_slider_content_type', $next_travel_pro_slider_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'next_travel_pro_gallery_slider_content_type' ) ) :
    /**
     * gallery_slider Options
     * @return array site gallery_slider options
     */
    function next_travel_pro_gallery_slider_content_type() {
      
        $next_travel_pro_gallery_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'next-travel-pro' ),
            'post'      => esc_html__( 'Post', 'next-travel-pro' ),
            'category'  => esc_html__( 'Category', 'next-travel-pro' ),
        );

        if ( class_exists( 'WP_Travel' )) {
            $next_travel_pro_gallery_slider_content_type = array_merge( $next_travel_pro_gallery_slider_content_type, array(
                'trip'          => esc_html__( 'Trip', 'next-travel-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'next-travel-pro' ),
                'destination'   => esc_html__( 'Destination', 'next-travel-pro' ),
                'activity'      => esc_html__( 'Activity', 'next-travel-pro' ),
                ) );
        }

        $output = apply_filters( 'next_travel_pro_gallery_slider_content_type', $next_travel_pro_gallery_slider_content_type );

        return $output;
    }
endif;


if ( ! function_exists( 'next_travel_pro_about_content_type' ) ) :
    /**
     * about Options
     * @return array site about options
     */
    function next_travel_pro_about_content_type() {
        $next_travel_pro_about_content_type = array(
            'page'      => esc_html__( 'Page', 'next-travel-pro' ),
            'post'      => esc_html__( 'Post', 'next-travel-pro' ),
            'custom'  => esc_html__( 'Custom', 'next-travel-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $next_travel_pro_about_content_type = array_merge( $next_travel_pro_about_content_type, array(
                'trip'    => esc_html__( 'Trips', 'next-travel-pro' ),
                ) );
        }

        $output = apply_filters( 'next_travel_pro_about_content_type', $next_travel_pro_about_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'next_travel_pro_featured_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function next_travel_pro_featured_content_type() {
        $next_travel_pro_featured_content_type = array(
            'category'  => esc_html__( 'Category', 'next-travel-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $next_travel_pro_featured_content_type = array_merge( $next_travel_pro_featured_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'next-travel-pro' ),
                'destination'   => esc_html__( 'Destination', 'next-travel-pro' ),
                'activity'      => esc_html__( 'Activity', 'next-travel-pro' ),
                ) );
        }

        $output = apply_filters( 'next_travel_pro_featured_content_type', $next_travel_pro_featured_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'next_travel_pro_popular_destination_content_type' ) ) :
    /**
     * Destination Options
     * @return array site Destination options
     */
    function next_travel_pro_popular_destination_content_type() {
        $next_travel_pro_popular_destination_content_type = array(
           'page'      => esc_html__( 'Page', 'next-travel-pro' ),
           'post'      => esc_html__( 'Post', 'next-travel-pro' ),
           'category'  => esc_html__( 'Category', 'next-travel-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $next_travel_pro_popular_destination_content_type = array_merge( $next_travel_pro_popular_destination_content_type, array(
                'trip'          => esc_html__( 'Trip', 'next-travel-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'next-travel-pro' ),
                'destination'   => esc_html__( 'Destination', 'next-travel-pro' ),
                'activity'      => esc_html__( 'Activity', 'next-travel-pro' ),
                ) );
        }

        $output = apply_filters( 'next_travel_pro_popular_destination_content_type', $next_travel_pro_popular_destination_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'next_travel_pro_recommended_destination_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function next_travel_pro_recommended_destination_content_type() {
        $next_travel_pro_recommended_destination_content_type = array(
            'page'      => esc_html__( 'Page', 'next-travel-pro' ),
            'post'       => esc_html__( 'Post', 'next-travel-pro' ),
            'category'  => esc_html__( 'Category', 'next-travel-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $next_travel_pro_recommended_destination_content_type = array_merge( $next_travel_pro_recommended_destination_content_type, array(
                'trip'          => esc_html__( 'Trips', 'next-travel-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'next-travel-pro' ),
                'destination'   => esc_html__( 'Destination', 'next-travel-pro' ),
                'activity'      => esc_html__( 'Activity', 'next-travel-pro' ),
                ) );
        }

        $output = apply_filters( 'next_travel_pro_recommended_destination_content_type', $next_travel_pro_recommended_destination_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'next_travel_pro_package_content_type' ) ) :
    /**
     * Package Options
     * @return array site gallery options
     */
    function next_travel_pro_package_content_type() {
        $next_travel_pro_package_content_type = array(
            'page'      => esc_html__( 'Page', 'next-travel-pro' ),
            'post'      => esc_html__( 'Post', 'next-travel-pro' ),
            'category'  => esc_html__( 'Category', 'next-travel-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $next_travel_pro_package_content_type = array_merge( $next_travel_pro_package_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'next-travel-pro' ),
                'destination'   => esc_html__( 'Destination', 'next-travel-pro' ),
                'activity'      => esc_html__( 'Activity', 'next-travel-pro' ),
                ) );
        }

        $output = apply_filters( 'next_travel_pro_package_content_type', $next_travel_pro_package_content_type );


        return $output;
    }
endif;
