<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */
if ( ! function_exists( 'next_travel_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Next Travel Pro 1.0.0
    */
function next_travel_pro_add_slider_section() {
    $options = next_travel_pro_get_theme_options();

        // Check if slider is enabled on frontpage
    $slider_enable = apply_filters( 'next_travel_pro_section_status', true, 'slider_section_enable' );

    if ( !in_array( $options['home_layout'], array( 'default-design-all', 'default-design', 'second-design', 'third-design', 'fourth-design', 'fifth-design', 'sixth-design' ) ) ) {
       $slider_enable = false;
   }

    if ( true !== $slider_enable ) {
        return false;
    }
        // Get slider section details
    $section_details = array();
    $section_details = apply_filters( 'next_travel_pro_filter_slider_section_details', $section_details );
    if ( empty( $section_details ) ) {
        return;
    }
    next_travel_pro_render_slider_section( $section_details );
}
endif;

if ( ! function_exists( 'next_travel_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Next Travel Pro 1.0.0
    * @param array $input slider section details.
    */
    function next_travel_pro_get_slider_section_details( $input ) {
        $options = next_travel_pro_get_theme_options();

        
        $slider_content_type  = $options['slider_content_type']; // Slider Content type.
        $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3; //Slider Post Count
        
        $content = array();
        switch ( $slider_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $slider_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_content_category'] ) ? $options['slider_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $slider_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_trip_' . $i] ) )
                        $page_ids[] = $options['slider_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );   

                $content['taxonomy'] = 'travel_locations';

            break;

			case 'trip-types': // trip-types
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$cat_id = ! empty( $options['slider_content_trip_types'] ) ? $options['slider_content_trip_types'] : array();

				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'itinerary_types',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $slider_count ),
                    );
                    
                $content['taxonomy'] = 'itinerary_types';
			break;

			
			case 'destination': //Destination
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$cat_id = ! empty( $options['slider_content_destination'] ) ? $options['slider_content_destination'] : array();
				
				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'travel_locations',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $slider_count ),
                    ); 
                    
				$content['taxonomy'] = 'travel_locations';
			break;

			case 'activity':
				if ( ! class_exists( 'WP_Travel' ) )
					return;
				
                $cat_id = ! empty( $options['slider_content_activity'] ) ? $options['slider_content_activity'] : array();
                
                if ( empty( $cat_id ) )
                    return;

				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'activity',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $slider_count ),
                    ); 
                    
                $content['taxonomy'] = 'activity';
			break;

            default:
            break;
        }

            $content['details'] = array();
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = next_travel_pro_trim_content( $options['slider_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content['details'], $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// slider section content details.
add_filter( 'next_travel_pro_filter_slider_section_details', 'next_travel_pro_get_slider_section_details' );


if ( ! function_exists( 'next_travel_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Next Travel Pro 1.0.0
   *
   */
   function next_travel_pro_render_slider_section( $content_details = array() ) {
        $options = next_travel_pro_get_theme_options();

        $slider_autoplay = ($options['slider_autoplay'] == true ) ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php if( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'default-design-all'): ?>

            <div id="featured-slider-section" class="slider-section">


                <div class="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": <?php echo esc_attr($slider_autoplay); ?>, "draggable": true, "fade": true, "adaptiveHeight": true }'>

              
                    <?php foreach ($content_details['details'] as $content) : ?>

                        <article style="background-image:url('<?php echo esc_url($content['image'])?>');">
    
                            <div class="wrapper">
                             <?php if ( is_customize_preview()): ?>                    
                                <?php next_travel_pro_section_tooltip( 'featured-slider-section' ); ?>
                            <?php endif; ?>
                                <div class="featured-content-wrapper">
                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html($content['excerpt']); ?></p>
                                        </div><!-- .entry-content -->
                                    </div><!-- .entry-container -->

                                    <?php if( $options['slider_search_enable'] == 'true' && class_exists( 'WP_Travel' ) ): ?>
                                        <div class="travel-search-section">
                                            <div class="wp-travel-search">
                                                <?php wptravel_search_form(); ?>
                                            </div>
                                        </div><!-- .travel-search-section -->
                                    <?php endif; ?>
                                </div><!-- .featured-content-wrapper -->
                            </div><!-- .wrapper -->
                        </article>

                    <?php endforeach; ?>

                </div><!-- .featured-slider -->
            </div><!-- #featured-slider-section -->  

        <?php endif; ?>

        <?php if (in_array( $options['home_layout'], array( 'second-design', 'third-design', 'fourth-design', 'fifth-design', 'sixth-design' ) ) ): ?>

            <div id="business-slider-section" class="slider-section">
                <div class="business-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": <?php echo esc_attr($slider_autoplay); ?>, "draggable": true, "fade": true, "adaptiveHeight": true }'>

                    <?php foreach ($content_details['details'] as $content) : ?>

                        <article style="background-image:url('<?php echo esc_url($content['image'])?>');">
                            <div class="overlay"></div>
                            <div class="wrapper">
                                <div class="featured-content-wrapper">
                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <p><?php echo esc_html($content['excerpt']); ?></p>
                                        </div><!-- .entry-content -->

                                        <?php if( !empty( $options['slider_btn_label'] ) ): ?>
                                            <div class="read-more">
                                                <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html( $options['slider_btn_label'] ); ?></a>
                                            </div><!-- .read-more -->
                                        <?php endif; ?>
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-content-wrapper -->
                            </div><!-- .wrapper -->
                        </article>

                    <?php endforeach; ?>

                </div><!-- .business-slider -->
            </div>

        <?php endif; ?>

    <?php }
endif;   