<?php
/**
 * Products collection section
 *
 * This is the template for the content of collection section
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */
if ( ! function_exists( 'next_travel_pro_add_collection_section' ) ) :
    /**
    * Add collection section
    *
    *@since Next Travel Pro 1.0.0
    */
    function next_travel_pro_add_collection_section() {
    	$options = next_travel_pro_get_theme_options();
        // Check if collection is enabled on frontpage
        $collection_enable = apply_filters( 'next_travel_pro_section_status', true, 'collection_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design-all', 'third-design' ) ) ) {
             $collection_enable = false;
        }

        if ( ( true !== $collection_enable) || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }

        // Render collection section now.
        next_travel_pro_render_collection_section();
    }
endif;

if ( ! function_exists( 'next_travel_pro_render_collection_section' ) ) :
  /**
   * Start collection section
   *
   * @return string collection content
   * @since Next Travel Pro 1.0.0
   *
   */
   function next_travel_pro_render_collection_section() {
        $options = next_travel_pro_get_theme_options();

    ?>
    
    <div id="products-collection" class="relative page-section same-background">
        <div class="wrapper">
            <div class="section-header">
        <?php if ( is_customize_preview()):
                next_travel_pro_section_tooltip( 'products-collection' );
                endif; ?>
                <?php if( !empty( $options['collection_subtitle'] ) ): ?>
                    <h3 class="section-subtitle"><?php echo esc_html( $options['collection_subtitle'] ); ?></h3>
                <?php endif;

                if( !empty( $options['collection_title'] ) ): 
                 ?>
             <h2 class="section-title"><?php echo esc_html( $options['collection_title'] ); ?></h2>
         <?php endif; ?>
         <span class="separator"></span>
     </div><!-- .section-header -->

     <div class="section-content grid col-2">

       <?php for ( $i=1; $i <= 4 ; $i++ ) { 
        if ( empty($options['collection_content_collection_category_'.$i]) ) {
            continue;
        }
        $thumbnail_id = get_term_meta( $options['collection_content_collection_category_'.$i], 'thumbnail_id', true );
        $image = wp_get_attachment_url( $thumbnail_id );
        $cat_name = get_term_by( 'id', $options['collection_content_collection_category_'.$i], 'product_cat' )->name;
        $banner_title = empty( $options['collection_banner_title_'.$i] ) ? '' : $options['collection_banner_title_'.$i];
        $cat_link = get_category_link( $options['collection_content_collection_category_'.$i] );
        ?>

        <article class="grid-item">
            <div class="featured-image" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                <div class="entry-container">
                    <span class="cat-links">
                        <ul class="post-categories">
                            <li><a href="<?php echo esc_url( $cat_link ); ?>"><?php echo esc_html( $cat_name ); ?></a></li>
                        </ul>
                    </span><!-- .cat-links -->

                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $cat_link ); ?>"><?php echo esc_html( $banner_title ); ?></a></h2>
                    </header>

                    <div class="read-more">
                        <a href="<?php echo esc_url( $cat_link ); ?>" class="btn"><?php echo esc_html__( 'Start Shopping', 'next-travel-pro' ); ?></a>
                    </div><!-- .read-more -->
                </div><!-- .entry-container -->
            </div><!-- .featured-image -->
        </article>

        <?php } ?>

    </div><!-- .section-content -->
</div><!-- .wrapper -->
</div><!-- #products-collction -->

    <?php }
endif;