<?php
/**
 * Recent News section
 *
 * This is the template for the content of recent_news section
 *
 * @package Theme Palace
 * @subpackage Next Travel Pro
 * @since Next Travel Pro 1.0.0
 */
if ( ! function_exists( 'next_travel_pro_add_recent_news_section' ) ) :
    /**
    * Add recent_news section
    *
    *@since Next Travel Pro 1.0.0
    */
    function next_travel_pro_add_recent_news_section() {
        $options = next_travel_pro_get_theme_options();
        // Check if recent_news is enabled on frontpage
        $recent_news_enable = apply_filters( 'next_travel_pro_section_status', true, 'recent_news_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design-all', 'second-design', 'third-design', 'fourth-design', 'fifth-design', 'sixth-design' ) ) ) {
            $recent_news_enable = false;
        }

        if ( true !== $recent_news_enable ) {
            return false;
        }
        // Get recent_news section details
        $section_details = array();
        $section_details = apply_filters( 'next_travel_pro_filter_recent_news_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render recent_news section now.
        next_travel_pro_render_recent_news_section( $section_details );
    }
endif;

if ( ! function_exists( 'next_travel_pro_get_recent_news_section_details' ) ) :
    /**
    * recent_news section details.
    *
    * @since Next Travel Pro 1.0.0
    * @param array $input recent_news section details.
    */
    function next_travel_pro_get_recent_news_section_details( $input ) {
        $options = next_travel_pro_get_theme_options();

        // Content type.
        $recent_news_content_type   = $options['recent_news_content_type'];
        $recent_news_count          = ! empty( $options['recent_news_count'] ) ? $options['recent_news_count'] : 3;
        $content = array();
        switch ( $recent_news_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $recent_news_count; $i++ ) {
                    if ( ! empty( $options['recent_news_content_page_' . $i] ) ) :
                        $page_ids[] = $options['recent_news_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $recent_news_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $recent_news_count; $i++ ) {
                    if ( ! empty( $options['recent_news_content_post_' . $i] ) ) :
                        $post_ids[] = $options['recent_news_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $recent_news_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['recent_news_content_category'] ) ? $options['recent_news_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $recent_news_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }
            
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['auth_id']   = get_the_author_meta('ID');
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = next_travel_pro_trim_content( $options['recent_news_excerpt_length'] );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent_news section content details.
add_filter( 'next_travel_pro_filter_recent_news_section_details', 'next_travel_pro_get_recent_news_section_details' );


if ( ! function_exists( 'next_travel_pro_render_recent_news_section' ) ) :
  /**
   * Start recent_news section
   *
   * @return string recent_news content
   * @since Next Travel Pro 1.0.0
   *
   */
   function next_travel_pro_render_recent_news_section( $content_details = array() ) {
        $options = next_travel_pro_get_theme_options();

        $recent_news_title     = ! empty( $options['recent_news_title'] ) ? $options['recent_news_title'] : '';
        $recent_news_sub_title = ! empty( $options['recent_news_sub_title'] ) ? $options['recent_news_sub_title'] : '';
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="recent-news" class="relative page-section same-background">
            <div class="wrapper">
             <?php if ( is_customize_preview()):
                next_travel_pro_section_tooltip( 'recent-news' );
                endif; ?>
                <div class="section-header">
                    <?php if( !empty( $recent_news_sub_title ) ): ?>
                        <h3 class="section-subtitle"><?php echo esc_html( $recent_news_sub_title ); ?></h3>
                    <?php endif; 
                    if( !empty( $recent_news_title ) ):
                        ?>
                    <h2 class="section-title"><?php echo esc_html( $recent_news_title ); ?></h2>
                <?php endif; ?>
                <span class="separator"></span>
            </div><!-- .section-header -->

                <div class="section-content col-3 clear">

                <?php $i=1; foreach ( $content_details as $content ): ?>

                    <article>
                        <div class="recent-news-item">
                            <div class="featured-image">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="news <?php echo esc_attr( $i+1 ); ?>"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-meta">
                                <?php 
                                echo next_travel_pro_author_meta($content['id']);

                                next_travel_pro_posted_on( $content['id'] ); ?>

                            </div><!-- .entry-meta -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <?php if( !empty( $options['recent_news_button'] ) ): ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['recent_news_button'] ); ?></a>
                            </div><!-- .read-more -->
                        <?php endif; ?>
                        </div><!-- team-item-wrapper -->
                    </article>

                <?php $i++; endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #recent-news -->

    <?php }
endif;
